@@ -18,7 +18,7 @@ use Mail::GnuPG;
 use MIME::Entity;
 
 # Specify package verson
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Default exit value
 const our $DEFAULT_EXIT => 127;
@@ -135,7 +135,7 @@ Mail::Run::Crypt - Encrypt and mail output from command runs
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 DESCRIPTION
 
@@ -185,29 +185,30 @@ Constructor method; accepts the following named parameters:
 
 The recipient email address for the content. This is always required.
 
+=item C<encrypt>
+
+Whether to encrypt the command output. This defaults to 1.
+
 =item C<sign>
 
 Whether to sign the command output. This defaults to 0. A C<keyid> and
 C<passphrase> will be required for signing.
 
-=item C<encrypt>
-
-Whether to encrypt the command output. This defaults to 1.
-
-=item C<keyid>
-
-The GnuPG key ID that should be used to encrypt the messages. This is required
-for signing. It can be any means of identifying the key acceptable to GnuPG;
-the key's 16-byte ("long") hexadecimal ID prefixed with C<0x> is probably the
-best way. 
-
 It is I<strongly> recommended that a dedicated key and passphrase be used for
 signatures if this is needed. You should carefully consider the consequences of
 a compromised key.
 
+=item C<keyid>
+
+The GnuPG key ID that should be used to sign messages. This is required for
+signing, and has no effect without C<sign>. It can be any means of identifying
+the key acceptable to GnuPG; the key's 16-byte ("long") hexadecimal ID prefixed
+with C<0x> is probably the best way.
+
 =item C<passphrase>
 
-The passphrase used to decrypt the key. This is required for signing.
+The passphrase used to decrypt the key. This is required for signing, and has
+no effect without C<sign>.
 
 =item C<name>
 
